@@ -12,7 +12,7 @@
 namespace dht
 {
 /*!
- * Error message in the DHT protocol
+ * \brief Error message in the DHT protocol.
  */
 class KTORRENT_EXPORT ErrMsg : public RPCMsg
 {
@@ -32,8 +32,6 @@ public:
         return msg;
     }
 
-    typedef QSharedPointer<ErrMsg> Ptr;
-
 private:
     QString msg;
 };
