@@ -32,7 +32,8 @@ const bt::Uint32 BUCKET_REFRESH_INTERVAL = 15 * 60 * 1000;
 /*!
  * \author Joris Guisson
  *
- * A KBucket is just a list of KBucketEntry objects.
+ * \brief A KBucket is just a list of KBucketEntry objects.
+ *
  * The list is sorted by time last seen :
  * The first element is the least recently seen, the last
  * the most recently seen.
@@ -46,7 +47,7 @@ public:
     KBucket(const dht::Key &min_key, const dht::Key &max_key, RPCServerInterface *srv, const Key &our_id);
     ~KBucket() override;
 
-    typedef QSharedPointer<KBucket> Ptr;
+    typedef std::unique_ptr<KBucket> Ptr;
 
     //! Get the min key
     const dht::Key &minKey() const
@@ -66,6 +67,9 @@ public:
     //! Are we allowed to split
     bool splitAllowed() const;
 
+    /*!
+     * \brief The exception thrown when attempting to split a KBucket that can only contain a single key.
+     */
     class UnableToSplit
     {
     };
@@ -128,13 +132,13 @@ public:
     void setRefreshTask(Task *t);
 
 private:
-    void onResponse(RPCCall *c, RPCMsg::Ptr rsp) override;
+    void onResponse(RPCCall *c, RPCMsg *rsp) override;
     void onTimeout(RPCCall *c) override;
     void pingQuestionable(const KBucketEntry &replacement_entry);
     bool replaceBadEntry(const KBucketEntry &entry);
 
 private Q_SLOTS:
-    void onFinished(Task *t);
+    void onFinished(dht::Task *t);
 
 private:
     dht::Key min_key, max_key;
