@@ -13,7 +13,7 @@
 namespace dht
 {
 /*!
- * Interface to resolve the method of an RPC call given an mtid
+ * \brief Interface to resolve the method of an RPC call given a message transaction ID.
  */
 class RPCMethodResolver
 {
@@ -27,7 +27,7 @@ public:
 };
 
 /*!
- * Creates RPC message objects out of a BDictNode
+ * \brief Creates RPC message objects out of a BDictNode.
  */
 class KTORRENT_EXPORT RPCMsgFactory
 {
@@ -42,11 +42,11 @@ public:
      * \return A newly created message
      * \throw bt::Error if something goes wrong
      */
-    RPCMsg::Ptr build(bt::BDictNode *dict, RPCMethodResolver *method_resolver);
+    std::unique_ptr<RPCMsg> build(bt::BDictNode *dict, RPCMethodResolver *method_resolver);
 
 private:
-    RPCMsg::Ptr buildRequest(bt::BDictNode *dict);
-    RPCMsg::Ptr buildResponse(bt::BDictNode *dict, RPCMethodResolver *method_resolver);
+    std::unique_ptr<RPCMsg> buildRequest(bt::BDictNode *dict);
+    std::unique_ptr<RPCMsg> buildResponse(bt::BDictNode *dict, RPCMethodResolver *method_resolver);
 };
 
 }
