@@ -26,8 +26,7 @@ const bt::Uint32 MAX_CONCURRENT_REQS = 16;
 /*!
  * \author Joris Guisson <joris.guisson@gmail.com>
  *
- * Performs a task on K nodes provided by a KClosestNodesSearch.
- * This is a base class for all tasks.
+ * \brief Interface class that performs a task on K nodes provided by a KClosestNodesSearch.
  */
 class Task : public RPCCallListener
 {
@@ -56,7 +55,7 @@ public:
     void start();
 
     //! Decrements the outstanding_reqs
-    void onResponse(RPCCall *c, RPCMsg::Ptr rsp) override;
+    void onResponse(RPCCall *c, RPCMsg *rsp) override;
 
     //! Decrements the outstanding_reqs
     void onTimeout(RPCCall *c) override;
@@ -72,7 +71,7 @@ public:
      * \param c The call
      * \param rsp The response
      */
-    virtual void callFinished(RPCCall *c, RPCMsg::Ptr rsp) = 0;
+    virtual void callFinished(RPCCall *c, RPCMsg *rsp) = 0;
 
     /*!
      * A call timedout
@@ -85,7 +84,7 @@ public:
      * \param req THe request to send
      * \return true if call was made, false if not
      */
-    bool rpcCall(RPCMsg::Ptr req);
+    bool rpcCall(std::unique_ptr<RPCMsg> req);
 
     //! See if we can do a request
     bool canDoRequest() const
@@ -130,14 +129,14 @@ Q_SIGNALS:
      * The task is finsihed.
      * \param t The Task
      */
-    void finished(Task *t);
+    void finished(dht::Task *t);
 
     /*!
      * Called by the task when data is ready.
      * Can be overrided if wanted.
      * \param t The Task
      */
-    void dataReady(Task *t);
+    void dataReady(dht::Task *t);
 
 protected:
     void done();
