@@ -20,8 +20,9 @@ namespace bt
 /*!
     \author Joris Guisson
 
-    HTTP connection for webseeding. We do not use KIO here, because we want to be able to apply
-    the maximum upload and download rate to webseeds;
+    \brief HTTP connection for webseeding.
+
+    We do not use KIO here, because we want to be able to apply the maximum upload and download rate to webseeds;
 */
 class HttpConnection : public QObject, public net::SocketReader, public net::StreamSocketListener
 {
@@ -164,9 +165,10 @@ private:
     QString status;
     QTimer connect_timer;
     QTimer reply_timer;
-    Uint32 up_gid, down_gid;
-    bool close_when_finished;
-    bool redirected;
+    Uint32 up_gid = 0;
+    Uint32 down_gid = 0;
+    bool close_when_finished = false;
+    bool redirected = false;
     QUrl redirected_url;
     int response_code;
 };
