@@ -19,8 +19,8 @@ class SHA1Hash;
 class PeerManager;
 
 /*!
-    Base class for all servers which accept connections.
-*/
+ * \brief Interface for all servers which accept connections.
+ */
 class KTORRENT_EXPORT ServerInterface : public QObject
 {
     Q_OBJECT
@@ -116,7 +116,7 @@ public:
     }
 
 protected:
-    void newConnection(mse::EncryptedPacketSocket::Ptr sock);
+    void newConnection(std::unique_ptr<mse::EncryptedPacketSocket> sock);
 
 protected:
     static Uint16 port;
