@@ -26,7 +26,7 @@ public Q_SLOTS:
 private Q_SLOTS:
     void initTestCase()
     {
-        bt::InitLibKTorrent();
+        QVERIFY(bt::InitLibKTorrent());
         bt::InitLog(u"polltest.log"_s);
     }
 
