@@ -15,6 +15,7 @@ struct TorrentStats;
 
 /*!
     \author Joris Guisson <joris.guisson@gmail.com>
+    \brief Choking algorithm that prioritizes local and new peers, and deprioritizes peers that haven't uploaded much data or have low bandwidth.
 */
 class AdvancedChokeAlgorithm : public ChokeAlgorithm
 {
@@ -26,9 +27,9 @@ public:
     void doChokingSeedingState(PeerManager &pman, ChunkManager &cman, const TorrentStats &stats) override;
 
 private:
-    bool calcACAScore(Peer::Ptr p, ChunkManager &cman, const TorrentStats &stats);
-    Peer::Ptr updateOptimisticPeer(PeerManager &pman, const QList<Peer::Ptr> &ppl);
-    void doUnchoking(const QList<Peer::Ptr> &ppl, Peer::Ptr poup);
+    bool calcACAScore(Peer *p, ChunkManager &cman, const TorrentStats &stats);
+    Peer *updateOptimisticPeer(PeerManager &pman, const QList<Peer *> &ppl);
+    void doUnchoking(const QList<Peer *> &ppl, Peer *poup);
 
 private:
     TimeStamp last_opt_sel_time; // last time we updated the optimistic unchoked peer
