@@ -12,16 +12,16 @@
 #include <interfaces/serverinterface.h>
 #include <ktorrent_export.h>
 
+#include <memory>
+
 namespace bt
 {
 class PeerManager;
 
-/**
- * @author Joris Guisson
+/*!
+ * \author Joris Guisson
  *
- * Class which listens for incoming connections.
- * Handles authentication and then hands of the new
- * connections to a PeerManager.
+ * \brief Listens for incoming connections, does the handshake, then hands off the new connections to a PeerManager.
  *
  * All PeerManager's should register with this class when they
  * are created and should unregister when they are destroyed.
@@ -37,7 +37,7 @@ public:
 
 private:
     class Private;
-    Private *d;
+    std::unique_ptr<Private> d;
 };
 
 }
