@@ -45,7 +45,7 @@ class DataCheckerJob;
 
 /*!
  * \author Joris Guisson
- * \brief Controls just about everything
+ * \brief Controls just about everything for a single torrent.
  *
  * This is the interface which any user gets to deal with.
  * This class controls the uploading, downloading, choking,
@@ -89,7 +89,7 @@ public:
     const BitSet &excludedChunksBitSet() const override;
     const BitSet &onlySeedChunksBitSet() const override;
     bool changeTorDir(const QString &new_dir) override;
-    bool changeOutputDir(const QString &new_dir, int flags) override;
+    bool changeOutputDir(const QString &new_dir, ChangeOutputOptions flags) override;
     void rollback() override;
     void setDisplayName(const QString &n) override;
     TrackersList *getTrackersList() override;
@@ -141,7 +141,7 @@ public:
     }
     void setAllowedToStart(bool on) override;
     void setQueued(bool queued) override;
-    void setChunkSelector(ChunkSelectorInterface *csel) override;
+    void setChunkSelector(std::unique_ptr<ChunkSelectorInterface> csel) override;
     void networkUp() override;
     bool announceAllowed() override;
     Job *startDataCheck(bool auto_import, bt::Uint32 from, bt::Uint32 to) override;
@@ -190,7 +190,7 @@ public:
     void setChunkSelectorFactory(ChunkSelectorFactoryInterface *csfi);
 
     //! Set a custom Cache factory
-    void setCacheFactory(CacheFactory *cf);
+    void setCacheFactory(std::unique_ptr<CacheFactory> cf);
 
     //! Get time in msec since the last Stats file save on disk
     TimeStamp getStatsSyncElapsedTime()
@@ -306,18 +306,18 @@ Q_SIGNALS:
     void dataCheckFinished();
 
 private:
-    JobQueue *job_queue;
+    JobQueue *job_queue; // lifetime managed by QObject
     QueueManagerInterface *m_qman;
-    Torrent *tor;
-    PeerSourceManager *psman;
-    ChunkManager *cman;
-    PeerManager *pman;
-    Downloader *downloader;
-    Uploader *uploader;
-    Choker *choke;
-    TimeEstimator *m_eta;
+    std::unique_ptr<Choker> choke;
+    std::unique_ptr<Downloader> downloader;
+    std::unique_ptr<Uploader> uploader;
+    std::unique_ptr<ChunkManager> cman;
+    std::unique_ptr<PeerManager> pman;
+    std::unique_ptr<PeerSourceManager> psman;
+    std::unique_ptr<Torrent> tor;
+    std::unique_ptr<TimeEstimator> m_eta;
     MonitorInterface *tmon;
-    CacheFactory *cache_factory;
+    std::unique_ptr<CacheFactory> cache_factory;
     QString move_data_files_destination_path;
     Timer choker_update_timer;
     Timer stats_save_timer;
@@ -330,7 +330,7 @@ private:
     QString completed_dir;
     bool prealloc;
     TimeStamp last_diskspace_check;
-    bool loading_stats;
+    bool loading_stats = false;
 
     struct InternalStats {
         QDateTime time_started_dl;
@@ -348,16 +348,17 @@ private:
         bool diskspace_warning_emitted;
     };
 
-    Uint32 upload_gid; // group ID for upload
-    Uint32 upload_limit;
-    Uint32 download_gid; // group ID for download
-    Uint32 download_limit;
+    // by default no torrent limits
+    Uint32 upload_gid = 0; // group ID for upload
+    Uint32 upload_limit = 0;
+    Uint32 download_gid = 0; // group ID for download
+    Uint32 download_limit = 0;
 
-    Uint32 assured_download_speed;
-    Uint32 assured_upload_speed;
+    Uint32 assured_download_speed = 0;
+    Uint32 assured_upload_speed = 0;
 
     InternalStats istats;
-    StatsFile *stats_file;
+    std::unique_ptr<StatsFile> stats_file;
 
     TorrentFileStream::WPtr stream;
 
