@@ -14,46 +14,48 @@ namespace bt
 class Peer;
 class ChunkManager;
 
-/**
- * @author Joris Guisson
+/*!
+ * \author Joris Guisson
  *
- * Class which manages the uploading of data. It has a PeerUploader for
- * each Peer.
+ * \brief Manages the uploading of a torrent.
+ *
+ * It has a PeerUploader for each Peer.
  */
 class Uploader : public QObject, public PeerManager::PeerVisitor
 {
     Q_OBJECT
 public:
-    /**
-     * Constructor, sets the ChunkManager.
-     * @param cman The ChunkManager
+    /*!
+     * Constructor, sets the ChunkManager and PeerManager.
+     * \param cman The ChunkManager
+     * \param pman The PeerManager
      */
     Uploader(ChunkManager &cman, PeerManager &pman);
     ~Uploader() override;
 
-    /// Get the number of bytes uploaded.
+    //! Get the number of bytes uploaded.
     Uint64 bytesUploaded() const
     {
         return uploaded;
     }
 
-    /// Get the upload rate of all Peers combined.
+    //! Get the upload rate of all Peers combined.
     Uint32 uploadRate() const;
 
-    /// Set the number of bytes which have been uploaded.
+    //! Set the number of bytes which have been uploaded.
     void setBytesUploaded(Uint64 b)
     {
         uploaded = b;
     }
 
 public Q_SLOTS:
-    /**
+    /*!
      * Update every PeerUploader.
      */
     void update();
 
 private:
-    void visit(const bt::Peer::Ptr p) override;
+    void visit(const bt::Peer *p) override;
 
 private:
     ChunkManager &cman;
