@@ -13,11 +13,12 @@ namespace bt
 {
 class Log;
 
-/**
-    @author Joris Guisson <joris.guisson@gmail.com>
+/*!
+    \author Joris Guisson <joris.guisson@gmail.com>
 
-    Job which handles the rotation of the log file.
-    This Job must do several move jobs which must be done sequentially.
+    \brief KIO::Job which handles the rotation of the log file.
+
+    This job must do several move jobs which must be done sequentially.
 */
 class AutoRotateLogJob : public KIO::Job
 {
