@@ -7,14 +7,14 @@
 #ifndef DECOMPRESSFILEJOB_H
 #define DECOMPRESSFILEJOB_H
 
+#include <KIO/Job>
 #include <QThread>
-#include <kio/job.h>
 #include <ktorrent_export.h>
 
 namespace bt
 {
-/**
- * Thread which decompresses a single file
+/*!
+ * \brief Thread which decompresses a single file.
  */
 class KTORRENT_EXPORT DecompressThread : public QThread
 {
@@ -22,13 +22,13 @@ public:
     DecompressThread(const QString &file, const QString &dest_file);
     ~DecompressThread() override;
 
-    /// Run the decompression thread
+    //! Run the decompression thread
     void run() override;
 
-    /// Cancel the thread, things should be cleaned up properly
+    //! Cancel the thread, things should be cleaned up properly
     void cancel();
 
-    /// Get the error which happened (0 means no error)
+    //! Get the error which happened (0 means no error)
     int error() const
     {
         return err;
@@ -41,9 +41,9 @@ private:
     int err;
 };
 
-/**
-    Decompress a file and remove it when completed successfully.
-*/
+/*!
+ * \brief Decompresses a file and removes it when completed successfully.
+ */
 class KTORRENT_EXPORT DecompressFileJob : public KIO::Job
 {
     Q_OBJECT
