@@ -60,7 +60,7 @@ void OutputQueue::send(net::ServerSocket *sock)
     sock->setWriteNotificationsEnabled(!queue.empty());
     lock.unlock(); // unlock, so we can't get deadlocked in any subsequent close calls
 
-    for (const utp::Connection::WPtr &conn : qAsConst(to_close)) {
+    for (const utp::Connection::WPtr &conn : std::as_const(to_close)) {
         Connection::Ptr c = conn.toStrongRef();
         if (c)
             c->close();
