@@ -8,6 +8,8 @@
 #include "version.h"
 #include <QString>
 
+using namespace Qt::Literals::StringLiterals;
+
 namespace bt
 {
 static QString g_name = QStringLiteral("KTorrent");
@@ -21,26 +23,26 @@ void SetClientInfo(const QString &name, const QString &version, const QString &p
     g_version = version;
     g_peer_id = peer_id;
     g_version_without_dots = g_version;
-    g_version_without_dots = g_version_without_dots.remove(QChar('.'));
+    g_version_without_dots = g_version_without_dots.remove('.'_L1);
 }
 
 [[deprecated]] void SetClientInfo(const QString &name, int major, int minor, int release, VersionType type, const QString &peer_id)
 {
     Q_UNUSED(type)
     g_name = name;
-    g_version = QString("%1.%2.%3").arg(major).arg(minor).arg(release);
+    g_version = u"%1.%2.%3"_s.arg(major).arg(minor).arg(release);
     g_peer_id = peer_id;
-    g_version_without_dots = QString("%1%2%3").arg(major).arg(minor).arg(release);
+    g_version_without_dots = u"%1%2%3"_s.arg(major).arg(minor).arg(release);
 }
 
 QString PeerIDPrefix()
 {
-    return QString("-%1%2-").arg(g_peer_id, g_version_without_dots);
+    return u"-%1%2-"_s.arg(g_peer_id, g_version_without_dots);
 }
 
 QString GetVersionString()
 {
-    QString str = g_name + QString("/%1").arg(g_version);
+    QString str = g_name + '/'_L1 + g_version;
     return str;
 }
 }
